@@ -5,11 +5,19 @@ class Currency(Object):
     def __init__(self, *args, **kwargs):
         super(Currency, self).__init__(*args, **kwargs)
 
-    @staticmethod
-    def round(value, decimals=0):
-        multiplier = float(10 ** decimals)
+        try:
+            self.rounding = float(self.rounding)
+        except (ValueError, TypeError):
+            self.rounding = .0
+
+    def round(self, value, decimals=0):
+        if not self.rounding:
+            multiplier = float(10 ** decimals)
+
+            return int(value * multiplier) / multiplier
+        else:
+            return int(self.rounding * int(value / self.rounding))
 
-        return int(value * multiplier) / multiplier
 
     def _format(self, value):
         return self.format % value
